@@ -105,7 +105,7 @@ public:
     }
 
     /**
-     * todo: is there a QT method that can be used insted of this?
+     * todo: is there a QT method that can be used instead of this?
      */
     static QString removeMenuAmpersand(const QString& str)
     {
@@ -134,7 +134,7 @@ public: // should be private but we would like to unit test
     {
         QList<const KmtMenuItemDto*> r;
 
-        Q_FOREACH (const auto& item, list) {
+        for (const auto& item : qAsConst(list)) {
             if (item.menuSection == menuSection) {
                 r.append(&item);
             }
@@ -195,7 +195,7 @@ public:
     void jsonWrite(QJsonObject &json) const
     {
         QJsonArray jArr;
-        Q_FOREACH (const auto item, list) {
+        for (const auto item : qAsConst(list)) {
             QJsonObject jObj;
             item.jsonWrite(jObj);
             jArr.append(jObj);
@@ -232,7 +232,7 @@ public: // should be private but we would like to unit test
 
 public:
     /**
-    * moves an item up or down respecting its catgory
+    * moves an item up or down respecting its category
     * @param direction: 1: down, -1: up
     */
     void moveWithinSection(const QString& id, int direction)
@@ -327,29 +327,29 @@ public:
     {
         KmtMenuStructureDto result;
 
-        Q_FOREACH (auto item, mainItems) {
+        for (auto item : qAsConst(mainItems)) {
             const auto a = item->action();
             KmtMenuItemDto dto;
             dto.id = item->id();
-            dto.text = a->text(); // might be overriden, so we use directly from QAction
+            dto.text = a->text(); // might be overridden, so we use directly from QAction
             dto.icon = a->icon();
             dto.isInstalled = true;
             dto.menuSection = KMoreTools::MenuSection_Main;
             result.list << dto;
         }
 
-        Q_FOREACH (auto item, moreItems) {
+        for (auto item : qAsConst(moreItems)) {
             const auto a = item->action();
             KmtMenuItemDto dto;
             dto.id = item->id();
-            dto.text = a->text(); // might be overriden, so we use directly from QAction
+            dto.text = a->text(); // might be overridden, so we use directly from QAction
             dto.icon = a->icon();
             dto.isInstalled = true;
             dto.menuSection = KMoreTools::MenuSection_More;
             result.list << dto;
         }
 
-        Q_FOREACH (auto registeredService, notInstalledServices) {
+        for (auto registeredService : qAsConst(notInstalledServices)) {
             KmtMenuItemDto dto;
             //dto.id = item->id(); // not used in this case
             dto.text = registeredService->formatString(_("$Name"));
